==> gimp_3.0.4.orig.tar.xz: gimp-3.0.4/app/tools/gimpcageoptions.h <==
/* GIMP - The GNU Image Manipulation Program
 *
 * gimpcageoptions.h
 * Copyright (C) 2010 Michael Muré <batolettre@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_CAGE_OPTIONS_H__
#define __GIMP_CAGE_OPTIONS_H__


#include "core/gimptooloptions.h"


#define GIMP_TYPE_CAGE_OPTIONS            (gimp_cage_options_get_type ())
#define GIMP_CAGE_OPTIONS(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_CAGE_OPTIONS, GimpCageOptions))
#define GIMP_CAGE_OPTIONS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_CAGE_OPTIONS, GimpCageOptionsClass))
#define GIMP_IS_CAGE_OPTIONS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_CAGE_OPTIONS))
#define GIMP_IS_CAGE_OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_CAGE_OPTIONS))
#define GIMP_CAGE_OPTIONS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_CAGE_OPTIONS, GimpCageOptionsClass))


typedef struct _GimpCageOptions      GimpCageOptions;
typedef struct _GimpCageOptionsClass GimpCageOptionsClass;

struct _GimpCageOptions
{
  GimpToolOptions  parent_instance;

  GimpCageMode     cage_mode;
  gboolean         fill_plain_color;
};

struct _GimpCageOptionsClass
{
  GimpToolOptionsClass  parent_class;
};


GType       gimp_cage_options_get_type (void) G_GNUC_CONST;

GtkWidget * gimp_cage_options_gui      (GimpToolOptions *tool_options);


#endif  /*  __GIMP_CAGE_OPTIONS_H__  */

==> gimp-3.1.4.tar.xz: gimp-3.1.4/app/tools/gimpcageoptions.h <==
/* GIMP - The GNU Image Manipulation Program
 *
 * gimpcageoptions.h
 * Copyright (C) 2010 Michael Muré <batolettre@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#pragma once

#include "core/gimptooloptions.h"


#define GIMP_TYPE_CAGE_OPTIONS            (gimp_cage_options_get_type ())
#define GIMP_CAGE_OPTIONS(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_CAGE_OPTIONS, GimpCageOptions))
#define GIMP_CAGE_OPTIONS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_CAGE_OPTIONS, GimpCageOptionsClass))
#define GIMP_IS_CAGE_OPTIONS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_CAGE_OPTIONS))
#define GIMP_IS_CAGE_OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_CAGE_OPTIONS))
#define GIMP_CAGE_OPTIONS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_CAGE_OPTIONS, GimpCageOptionsClass))


typedef struct _GimpCageOptions      GimpCageOptions;
typedef struct _GimpCageOptionsClass GimpCageOptionsClass;

struct _GimpCageOptions
{
  GimpToolOptions  parent_instance;

  GimpCageMode     cage_mode;
  gboolean         fill_plain_color;
};

struct _GimpCageOptionsClass
{
  GimpToolOptionsClass  parent_class;
};


GType       gimp_cage_options_get_type (void) G_GNUC_CONST;

GtkWidget * gimp_cage_options_gui      (GimpToolOptions *tool_options);
